======
autonl
======

autonl automatically formats newline at end of file.


Installation
============

Installing from PyPI::

    pip install --upgrade autonl


Usage
=====

Formatting newline at end of file::

    autonl <filename>
